==> Transmission-0.4.tar.gz: Transmission-0.4/libtransmission/fdlimit.h <==
/******************************************************************************
 * Copyright (c) 2005 Eric Petit
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

typedef struct tr_fd_s tr_fd_t;

tr_fd_t * tr_fdInit();

FILE *    tr_fdFileOpen         ( tr_fd_t *, char * );
void      tr_fdFileRelease      ( tr_fd_t *, FILE * );
void      tr_fdFileClose        ( tr_fd_t *, char * );

int       tr_fdSocketWillCreate ( tr_fd_t *, int );
void      tr_fdSocketClosed     ( tr_fd_t *, int );

void      tr_fdClose            ( tr_fd_t * );

==> Transmission-0.6.1.tar.gz: Transmission-0.6.1/libtransmission/fdlimit.h <==
/******************************************************************************
 * $Id: fdlimit.h 261 2006-05-29 21:27:31Z titer $
 *
 * Copyright (c) 2005-2006 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

typedef struct tr_fd_s tr_fd_t;

tr_fd_t * tr_fdInit();

int       tr_fdFileOpen         ( tr_fd_t *, char * );
void      tr_fdFileRelease      ( tr_fd_t *, int );
void      tr_fdFileClose        ( tr_fd_t *, char * );

int       tr_fdSocketWillCreate ( tr_fd_t *, int );
void      tr_fdSocketClosed     ( tr_fd_t *, int );

void      tr_fdClose            ( tr_fd_t * );
